@@ -18,7 +18,7 @@
 
 #ifdef WITH_TLS
 /**
- * $Id: 2a6683d471f2e6d4f425003a8487ec447c5a305e $
+ * $Id: 7bb994b3242fada0c99823e632ca63d99ebfc47f $
  *
  * @file tls.h
  * @brief Structures and prototypes for TLS wrappers
@@ -26,7 +26,7 @@
  * @copyright 2010 Network RADIUS SARL <info@networkradius.com>
  */
 
-RCSIDH(tls_h, "$Id: 2a6683d471f2e6d4f425003a8487ec447c5a305e $")
+RCSIDH(tls_h, "$Id: 7bb994b3242fada0c99823e632ca63d99ebfc47f $")
 
 #include <freeradius/conffile.h>
 
@@ -94,7 +94,7 @@ typedef struct _record_t {
 } record_t;
 
 typedef struct _tls_info_t {
-	int		origin;
+	int		origin;		// 0 - received (from peer), 1 - sending (to peer)
 	int		content_type;
 	uint8_t		handshake_type;
 	uint8_t		alert_level;
@@ -103,7 +103,6 @@ typedef struct _tls_info_t {
 
 	char 		info_description[256];
 	size_t		record_len;
-	int		version;
 } tls_info_t;
 
 #if OPENSSL_VERSION_NUMBER < 0x10001000L
@@ -342,6 +341,7 @@ fr_tls_status_t tls_application_data(tls_session_t *ssn, REQUEST *request);
 #define FR_TLS_EX_INDEX_STORE	 (14)
 #define FR_TLS_EX_INDEX_SSN	 (15)
 #define FR_TLS_EX_INDEX_TALLOC	 (16)
+#define FR_TLS_EX_INDEX_FIX_CERT_ORDER (17)
 
 extern int fr_tls_ex_index_certs;
 extern int fr_tls_ex_index_vps;
@@ -367,7 +367,6 @@ struct fr_tls_server_conf_t {
 	bool		disable_tlsv1;
 	bool		disable_tlsv1_1;
 	bool		disable_tlsv1_2;
-	bool		tls13_enable_magic;
 	bool		disallow_untrusted;		//!< allow untrusted CAs to issue client certificates
 
 	int		min_version;
@@ -390,6 +389,7 @@ struct fr_tls_server_conf_t {
 	char const	*cipher_list;
 	bool		cipher_server_preference;
 	char const	*check_cert_issuer;
+	char const	*sigalgs_list;
 
 	bool     	session_cache_enable;
 	uint32_t     	session_lifetime;
@@ -405,6 +405,8 @@ struct fr_tls_server_conf_t {
 	char const	*verify_client_cert_cmd;
 	bool		require_client_cert;
 
+	bool		fix_cert_order;
+
 	pthread_mutex_t	mutex;
 
 #if 1
